@@ -37,17 +37,21 @@ class ClientProtocol(asyncio.Protocol):
 
 
 class EchoClientProtocol:
-    
-    transport = None
 
-    def __new__(cls, path, loop):
+    transport = None
+    loop = None
+    path = None
+
+    def __new__(cls, path=None, loop=None):
         if not hasattr(cls, '_instance'):
             cls._instance = super().__new__(cls)
         return cls._instance
 
-    def __init__(self, path: str, loop):
-        self.path = path
-        self.loop = loop
+    def __init__(self, path: str = None, loop=None):
+        if not self.loop:
+            self.loop = loop
+        if not self.path:
+            self.path = path
 
     def _processing_data(self, mtype: str, data):
         '''将传入的数据转为服务端可读取的数据'''
