@@ -25,7 +25,7 @@ class ServerProtocol(asyncio.Protocol):
         self.kwargs = kwargs
 
     def connection_made(self, transport):
-        logger.info(id(self))
+        logger.debug(id(self))
         self.transport = transport
 
     def data_received(self, data):
@@ -37,13 +37,13 @@ class ServerProtocol(asyncio.Protocol):
         try:
             if mtype in MESSAGE_PROTOCOL:
                 self.data = resolve_msg_protocol(data)
-                logger.info("Task Meta received: {!r}".format(self.data))
+                logger.debug("Task Meta received: {!r}".format(self.data))
             elif mtype in HEADER_PROTOCOL:
                 self.data = resolve_header_protocol(data)
-                logger.info("Task Meta received: {!r}".format(self.data))
+                logger.debug("Task Meta received: {!r}".format(self.data))
             elif mtype in DETAILLIST_PROTOCOL:
                 self.data = list(resolve_detaillist_protocol(data))
-                logger.info("Task Meta received: {!r}".format(self.data))
+                logger.debug("Task Meta received: {!r}".format(self.data))
             else:
                 logger.error(f"Unsupported mtype: {chr(mtype)}")
                 raise ValueError(f"Unsupported mtype: {chr(mtype)}")
@@ -58,7 +58,7 @@ class ServerProtocol(asyncio.Protocol):
         if error:
             logger.error('SERVER ERROR: {}'.format(error))
         else:
-            logger.info('Client Closed')
+            logger.debug('Client Closed')
         super().connection_lost(error)
 
 
